//  Define the swig module name.
%module pygdsio

//  The following code snippet was requested by Patrick Brockill to use
//  char* for arguments for his low-latency applications
%begin %{
#define SWIG_PYTHON_STRICT_BYTE_CHAR
%}

//  The following code is copied verbatim to the wrapper file.
//  Note that this code is not passed through CPP
%{
#define SWIG_FILE_WITH_INIT
#include "Dacc.hh"
#include "TSeries.hh"
#include "FrWriter.hh"
#include "lsmp_rw.hh"
%}

%include "std_string.i"

//  ANSI C/C++ wrapper declarations.

class Dacc {
 public:
  Dacc(void);
  ~Dacc(void);
  void addChannel(const char* name);
  void addFile(const char* path);
  void addFileList(const char* path);
  void rmChannel(const char*);
  int fillData(double stride);
  const TSeries* refData(const char*) const;
  int seek(Time);
  Time getFillTime();
};

%apply int& OUTPUT {int& read_data_ret};
%apply std::string& OUTPUT {std::string& read_data_bytes};
%apply unsigned long& OUTPUT {unsigned long& read_data_timestamp};

class FrWriter {
 public:
  FrWriter(const char* Name, int Run);
  ~FrWriter();
  int open(const char* File, bool toc);
  void close(void);
  void erase(void);
  int writeFrame(void);
  int buildFrame(const Time& Start, double dT);
  bool is_open(void) const;
  void addProcSeries(const char* Name, const TSeries& TS);
  void addRawSeries(const char* Name, const TSeries& TS);
  void addWriterHistory(void);
  void addHistory(const std::string& Name, const Time& t, 
		  const std::string& cmt);
};

class ShmWriter {
public:
    ShmWriter();
    ~ShmWriter();
    const bool connect(const char *name, const int num_buffers, const int blocksize, const int buffer_mode);
    const int write_data(std::string write_data_bytes, const unsigned long timestamp) const;
    const bool has_crc(const std::string data) const;
    const bool check_crc(const std::string data) const;
private:
    std::string partition_name;
    LSMP_PROD *partition;
};

class ShmReader {
public:
    ShmReader();
    ~ShmReader();
    const bool connect(const char *name);
    void read_data(int& read_data_ret, std::string& read_data_bytes, unsigned long& read_data_timestamp);
    const bool has_crc(const std::string data);
    const bool check_crc(const std::string data);

private:
    std::string partition_name;
    LSMP_CON *partition;
};

class ShmKill {
public:
    bool kill(char* name);
};

